<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="预警类型" prop="earlyWarningType">
        <el-select v-model="queryParams.earlyWarningType" placeholder="请选择预警类型" clearable>
          <el-option v-for="dict in earlyWarningTypeOptions" :key="dict.dictValue" :label="dict.dictLabel" :value="dict.dictValue" />
        </el-select>
      </el-form-item>
      <el-form-item label="标题" prop="title"><el-input v-model="queryParams.title" placeholder="请输入标题" clearable @keyup.enter.native="handleQuery" /></el-form-item>
      <el-form-item label="发送标志" prop="sendFlag">
        <el-select v-model="queryParams.sendFlag" placeholder="请选择发送标志" clearable>
          <el-option v-for="dict in sendFlagOptions" :key="dict.dictValue" :label="dict.dictLabel" :value="dict.dictValue" />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5"><el-button type="primary" icon="el-icon-plus" @click="handleAdd" v-hasPermi="['management:warning:add']">新增</el-button></el-col>
      <el-col :span="1.5"><el-button type="success" icon="el-icon-edit" :disabled="single" @click="handleUpdate" v-hasPermi="['management:warning:edit']">修改</el-button></el-col>
      <el-col :span="1.5">
        <el-button type="danger" icon="el-icon-delete" :disabled="multiple" @click="handleDelete" v-hasPermi="['management:warning:remove']">删除</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" border :data="warningList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="预警信息" align="center" prop="earlyWarningId" />
      <el-table-column label="预警类型" align="center" prop="earlyWarningType" :formatter="earlyWarningTypeFormat" />
      <el-table-column label="标题" align="center" prop="title" />
      <el-table-column label="范围" align="center" prop="rangeText" />
      <el-table-column label="内容" align="center" prop="content" />
      <el-table-column label="备注" align="center" prop="remarks" />
      <el-table-column label="发送标志" align="center" prop="sendFlag" :formatter="sendFlagFormat" />
      <el-table-column label="发送时间" align="center" prop="createTime" width="150" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button v-if="scope.row.sendFlag == '0'" type="text" icon="el-icon-position" @click="handleSend(scope.row)" v-hasPermi="['management:warning:send']">发送</el-button>
          <el-button v-if="scope.row.sendFlag == '0'" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)" v-hasPermi="['management:warning:edit']">修改</el-button>
          <el-button type="text" icon="el-icon-delete" @click="handleDelete(scope.row)" v-hasPermi="['management:warning:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize" @pagination="getList" />

    <!-- 添加或修改预警信息对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="预警类型" prop="earlyWarningType">
          <el-select v-model="form.earlyWarningType" placeholder="请选择预警类型">
            <el-option v-for="dict in earlyWarningTypeOptions" :key="dict.dictValue" :label="dict.dictLabel" :value="dict.dictValue"></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="标题" prop="title"><el-input v-model="form.title" placeholder="请输入标题" /></el-form-item>
        <el-form-item label="范围" prop="rangeText"><el-input v-model="form.rangeText" placeholder="请输入范围" /></el-form-item>
        <el-form-item label="内容" prop="content"><el-input v-model="form.content" placeholder="请输入内容" /></el-form-item>
        <el-form-item label="备注" prop="remarks"><el-input v-model="form.remarks" placeholder="请输入备注" /></el-form-item>
        <el-form-item label="发送标志">
          <el-radio-group v-model="form.sendFlag" disabled>
            <el-radio v-for="dict in sendFlagOptions" :key="dict.dictValue" :label="dict.dictValue">{{ dict.dictLabel }}</el-radio>
          </el-radio-group>
        </el-form-item>
        <!-- <el-form-item label="发送人" prop="sendAt">
          <el-input v-model="form.sendAt" placeholder="请输入发送人" />
        </el-form-item> -->
        <el-form-item label="发送时间" prop="sendTime"><el-input v-model="form.sendTime" disabled placeholder="发送时间" /></el-form-item>
        <!-- <el-form-item label="创建人" prop="createAt">
          <el-input v-model="form.createAt" placeholder="请输入创建人" />
        </el-form-item> -->
        <el-form-item label="创建时间" prop="createTime"><el-input v-model="form.createTime" disabled placeholder="创建时间" /></el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listWarning, getWarning, delWarning, addWarning, updateWarning, exportWarning, sendWarning } from '@/api/management/warning';

export default {
  name: 'Warning',
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 预警信息表格数据
      warningList: [],
      // 弹出层标题
      title: '',
      // 是否显示弹出层
      open: false,
      // 预警类型字典
      earlyWarningTypeOptions: [],
      // 发送标志字典
      sendFlagOptions: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        earlyWarningType: null,
        title: null,
        sendFlag: null,
        orderByColumn: 'createTime', //排序字段
        isAsc: 'desc' //排序方式
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        earlyWarningType: [{ required: true, message: '请选择预警类型' }],
        title: [{ required: true, message: '请输入标题' }],
        content: [{ required: true, message: '请输入内容' }]
      }
    };
  },
  created() {
    this.getList();
    this.getDicts('early_warning_type').then(response => {
      this.earlyWarningTypeOptions = response.data;
    });
    this.getDicts('send_flag').then(response => {
      this.sendFlagOptions = response.data;
    });
  },
  methods: {
    /** 查询预警信息列表 */
    getList() {
      this.loading = true;
      listWarning(this.queryParams).then(response => {
        this.warningList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 预警类型字典翻译
    earlyWarningTypeFormat(row, column) {
      return this.selectDictLabel(this.earlyWarningTypeOptions, row.earlyWarningType);
    },
    // 发送标志字典翻译
    sendFlagFormat(row, column) {
      return this.selectDictLabel(this.sendFlagOptions, row.sendFlag);
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        earlyWarningId: null,
        earlyWarningType: null,
        title: null,
        rangeText: null,
        content: null,
        remarks: null,
        sendFlag: '0',
        sendAt: null,
        sendTime: null,
        createAt: null,
        createTime: null
      };
      this.resetForm('form');
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm('queryForm');
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.earlyWarningId);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = '添加预警信息';
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const earlyWarningId = row.earlyWarningId || this.ids;
      getWarning(earlyWarningId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = '修改预警信息';
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs['form'].validate(valid => {
        if (valid) {
          if (this.form.earlyWarningId != null) {
            updateWarning(this.form).then(response => {
              this.msgSuccess('修改成功');
              this.open = false;
              this.getList();
            });
          } else {
            addWarning(this.form).then(response => {
              this.msgSuccess('新增成功');
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const earlyWarningIds = row.earlyWarningId || this.ids;
      this.$confirm('是否确认删除预警信息编号为"' + earlyWarningIds + '"的数据项?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(function() {
          return delWarning(earlyWarningIds);
        })
        .then(() => {
          this.getList();
          this.msgSuccess('删除成功');
        })
        .catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有预警信息数据项?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(() => {
          this.exportLoading = true;
          return exportWarning(queryParams);
        })
        .then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        })
        .catch(() => {});
    },
    handleSend(row) {
      row.sendFlag = 1;
      sendWarning(row).then(res => {
        this.msgSuccess('发送成功');
      });
    }
  }
};
</script>
